@@ -1,11 +1,12 @@
+import builtins
 import datetime
 from files_sdk.api import Api
 from files_sdk.exceptions import InvalidParameterError, MissingParameterError, NotImplementedError
 
 class FileAction:
     default_attributes = {
-        'status': None,     # string - Status of file operation. Possible values: completed, enqueued.
-        'file_migration_id': None,     # int64 - If status is enqueued, this is the id of the FileMigration to check for status updates.
+        'status': None,     # string - Status of file operation.
+        'file_migration_id': None,     # int64 - If status is pending, this is the id of the FileMigration to check for status updates.
         'path': None,
         'destination': None,
     }
