@@ -1,3 +1,4 @@
+import builtins
 import datetime
 from files_sdk.api import Api
 from files_sdk.list_obj import ListObj
@@ -9,10 +10,19 @@ class Notification:
         'path': None,     # string - Folder path to notify on This must be slash-delimited, but it must neither start nor end with a slash. Maximum of 5000 characters.
         'group_id': None,     # int64 - Notification group id
         'group_name': None,     # string - Group name if applicable
+        'triggering_group_ids': None,     # array - Only notify on actions made by a member of one of the specified groups
+        'triggering_user_ids': None,     # array - Only notify on actions made one of the specified users
+        'trigger_by_share_recipients': None,     # boolean - Notify when actions are performed by a share recipient?
         'notify_user_actions': None,     # boolean - Trigger notification on notification user actions?
-        'notify_on_copy': None,     # boolean - Triggers notification when moving or copying files to this path
+        'notify_on_copy': None,     # boolean - Triggers notification when copying files to this path
+        'notify_on_delete': None,     # boolean - Triggers notification when deleting files from this path
+        'notify_on_download': None,     # boolean - Triggers notification when downloading files from this path
+        'notify_on_move': None,     # boolean - Triggers notification when moving files to this path
+        'notify_on_upload': None,     # boolean - Triggers notification when uploading new files to this path
         'recursive': None,     # boolean - Enable notifications for each subfolder in this path
         'send_interval': None,     # string - The time interval that notifications are aggregated to
+        'message': None,     # string - Custom message to include in notification emails.
+        'triggering_filenames': None,     # array - Array of filenames (possibly with wildcards) to match for action path
         'unsubscribed': None,     # boolean - Is the user unsubscribed from this notification?
         'unsubscribed_reason': None,     # string - The reason that the user unsubscribed
         'user_id': None,     # int64 - Notification user ID
@@ -37,9 +47,18 @@ class Notification:
 
     # Parameters:
     #   notify_on_copy - boolean - If `true`, copying or moving resources into this path will trigger a notification, in addition to just uploads.
+    #   notify_on_delete - boolean - Triggers notification when deleting files from this path
+    #   notify_on_download - boolean - Triggers notification when downloading files from this path
+    #   notify_on_move - boolean - Triggers notification when moving files to this path
+    #   notify_on_upload - boolean - Triggers notification when uploading new files to this path
     #   notify_user_actions - boolean - If `true` actions initiated by the user will still result in a notification
     #   recursive - boolean - If `true`, enable notifications for each subfolder in this path
     #   send_interval - string - The time interval that notifications are aggregated by.  Can be `five_minutes`, `fifteen_minutes`, `hourly`, or `daily`.
+    #   message - string - Custom message to include in notification emails.
+    #   triggering_filenames - array(string) - Array of filenames (possibly with wildcards) to match for action path
+    #   triggering_group_ids - array(int64) - Only notify on actions made by a member of one of the specified groups
+    #   triggering_user_ids - array(int64) - Only notify on actions made one of the specified users
+    #   trigger_by_share_recipients - boolean - Notify when actions are performed by a share recipient?
     def update(self, params = None):
         if not isinstance(params, dict):
             params = {}
@@ -54,6 +73,14 @@ class Notification:
             raise InvalidParameterError("Bad parameter: id must be an int")
         if "send_interval" in params and not isinstance(params["send_interval"], str):
             raise InvalidParameterError("Bad parameter: send_interval must be an str")
+        if "message" in params and not isinstance(params["message"], str):
+            raise InvalidParameterError("Bad parameter: message must be an str")
+        if "triggering_filenames" in params and not isinstance(params["triggering_filenames"], builtins.list):
+            raise InvalidParameterError("Bad parameter: triggering_filenames must be an list")
+        if "triggering_group_ids" in params and not isinstance(params["triggering_group_ids"], builtins.list):
+            raise InvalidParameterError("Bad parameter: triggering_group_ids must be an list")
+        if "triggering_user_ids" in params and not isinstance(params["triggering_user_ids"], builtins.list):
+            raise InvalidParameterError("Bad parameter: triggering_user_ids must be an list")
         response, _options = Api.send_request("PATCH", "/notifications/{id}".format(id=params['id']), params, self.options)
         return response.data
 
@@ -84,15 +111,15 @@ class Notification:
 
 # Parameters:
 #   user_id - int64 - DEPRECATED: Show notifications for this User ID. Use `filter[user_id]` instead.
-#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
+#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via either the X-Files-Cursor-Next header or the X-Files-Cursor-Prev header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
 #   sort_by - object - If set, sort records by the specified field in either 'asc' or 'desc' direction (e.g. sort_by[last_login_at]=desc). Valid fields are `path`, `user_id` or `group_id`.
-#   filter - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `user_id`, `group_id` or `path`.
-#   filter_gt - object - If set, return records where the specifiied field is greater than the supplied value. Valid fields are `user_id`, `group_id` or `path`.
-#   filter_gteq - object - If set, return records where the specifiied field is greater than or equal to the supplied value. Valid fields are `user_id`, `group_id` or `path`.
-#   filter_like - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `user_id`, `group_id` or `path`.
-#   filter_lt - object - If set, return records where the specifiied field is less than the supplied value. Valid fields are `user_id`, `group_id` or `path`.
-#   filter_lteq - object - If set, return records where the specifiied field is less than or equal to the supplied value. Valid fields are `user_id`, `group_id` or `path`.
+#   filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `user_id`, `group_id` or `path`.
+#   filter_gt - object - If set, return records where the specified field is greater than the supplied value. Valid fields are `user_id`, `group_id` or `path`.
+#   filter_gteq - object - If set, return records where the specified field is greater than or equal to the supplied value. Valid fields are `user_id`, `group_id` or `path`.
+#   filter_like - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `user_id`, `group_id` or `path`.
+#   filter_lt - object - If set, return records where the specified field is less than the supplied value. Valid fields are `user_id`, `group_id` or `path`.
+#   filter_lteq - object - If set, return records where the specified field is less than or equal to the supplied value. Valid fields are `user_id`, `group_id` or `path`.
 #   group_id - int64 - DEPRECATED: Show notifications for this Group ID. Use `filter[group_id]` instead.
 #   path - string - Show notifications for this Path.
 #   include_ancestors - boolean - If `include_ancestors` is `true` and `path` is specified, include notifications for any parent paths. Ignored if `path` is not specified.
@@ -151,9 +178,18 @@ def get(id, params = None, options = None):
 # Parameters:
 #   user_id - int64 - The id of the user to notify. Provide `user_id`, `username` or `group_id`.
 #   notify_on_copy - boolean - If `true`, copying or moving resources into this path will trigger a notification, in addition to just uploads.
+#   notify_on_delete - boolean - Triggers notification when deleting files from this path
+#   notify_on_download - boolean - Triggers notification when downloading files from this path
+#   notify_on_move - boolean - Triggers notification when moving files to this path
+#   notify_on_upload - boolean - Triggers notification when uploading new files to this path
 #   notify_user_actions - boolean - If `true` actions initiated by the user will still result in a notification
 #   recursive - boolean - If `true`, enable notifications for each subfolder in this path
 #   send_interval - string - The time interval that notifications are aggregated by.  Can be `five_minutes`, `fifteen_minutes`, `hourly`, or `daily`.
+#   message - string - Custom message to include in notification emails.
+#   triggering_filenames - array(string) - Array of filenames (possibly with wildcards) to match for action path
+#   triggering_group_ids - array(int64) - Only notify on actions made by a member of one of the specified groups
+#   triggering_user_ids - array(int64) - Only notify on actions made one of the specified users
+#   trigger_by_share_recipients - boolean - Notify when actions are performed by a share recipient?
 #   group_id - int64 - The ID of the group to notify.  Provide `user_id`, `username` or `group_id`.
 #   path - string - Path
 #   username - string - The username of the user to notify.  Provide `user_id`, `username` or `group_id`.
@@ -166,6 +202,14 @@ def create(params = None, options = None):
         raise InvalidParameterError("Bad parameter: user_id must be an int")
     if "send_interval" in params and not isinstance(params["send_interval"], str):
         raise InvalidParameterError("Bad parameter: send_interval must be an str")
+    if "message" in params and not isinstance(params["message"], str):
+        raise InvalidParameterError("Bad parameter: message must be an str")
+    if "triggering_filenames" in params and not isinstance(params["triggering_filenames"], builtins.list):
+        raise InvalidParameterError("Bad parameter: triggering_filenames must be an list")
+    if "triggering_group_ids" in params and not isinstance(params["triggering_group_ids"], builtins.list):
+        raise InvalidParameterError("Bad parameter: triggering_group_ids must be an list")
+    if "triggering_user_ids" in params and not isinstance(params["triggering_user_ids"], builtins.list):
+        raise InvalidParameterError("Bad parameter: triggering_user_ids must be an list")
     if "group_id" in params and not isinstance(params["group_id"], int):
         raise InvalidParameterError("Bad parameter: group_id must be an int")
     if "path" in params and not isinstance(params["path"], str):
@@ -177,9 +221,18 @@ def create(params = None, options = None):
 
 # Parameters:
 #   notify_on_copy - boolean - If `true`, copying or moving resources into this path will trigger a notification, in addition to just uploads.
+#   notify_on_delete - boolean - Triggers notification when deleting files from this path
+#   notify_on_download - boolean - Triggers notification when downloading files from this path
+#   notify_on_move - boolean - Triggers notification when moving files to this path
+#   notify_on_upload - boolean - Triggers notification when uploading new files to this path
 #   notify_user_actions - boolean - If `true` actions initiated by the user will still result in a notification
 #   recursive - boolean - If `true`, enable notifications for each subfolder in this path
 #   send_interval - string - The time interval that notifications are aggregated by.  Can be `five_minutes`, `fifteen_minutes`, `hourly`, or `daily`.
+#   message - string - Custom message to include in notification emails.
+#   triggering_filenames - array(string) - Array of filenames (possibly with wildcards) to match for action path
+#   triggering_group_ids - array(int64) - Only notify on actions made by a member of one of the specified groups
+#   triggering_user_ids - array(int64) - Only notify on actions made one of the specified users
+#   trigger_by_share_recipients - boolean - Notify when actions are performed by a share recipient?
 def update(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
@@ -190,6 +243,14 @@ def update(id, params = None, options = None):
         raise InvalidParameterError("Bad parameter: id must be an int")
     if "send_interval" in params and not isinstance(params["send_interval"], str):
         raise InvalidParameterError("Bad parameter: send_interval must be an str")
+    if "message" in params and not isinstance(params["message"], str):
+        raise InvalidParameterError("Bad parameter: message must be an str")
+    if "triggering_filenames" in params and not isinstance(params["triggering_filenames"], builtins.list):
+        raise InvalidParameterError("Bad parameter: triggering_filenames must be an list")
+    if "triggering_group_ids" in params and not isinstance(params["triggering_group_ids"], builtins.list):
+        raise InvalidParameterError("Bad parameter: triggering_group_ids must be an list")
+    if "triggering_user_ids" in params and not isinstance(params["triggering_user_ids"], builtins.list):
+        raise InvalidParameterError("Bad parameter: triggering_user_ids must be an list")
     if "id" not in params:
         raise MissingParameterError("Parameter missing: id")
     response, options = Api.send_request("PATCH", "/notifications/{id}".format(id=params['id']), params, options)
