@@ -1,3 +1,4 @@
+import builtins
 import datetime
 from files_sdk.api import Api
 from files_sdk.exceptions import InvalidParameterError, MissingParameterError, NotImplementedError
@@ -6,6 +7,8 @@ class PublicIpAddress:
     default_attributes = {
         'ip_address': None,     # string - The public IP address.
         'server_name': None,     # string - The name of the frontend server.
+        'ftp_enabled': None,     # boolean
+        'sftp_enabled': None,     # boolean
     }
 
     def __init__(self, attributes=None, options=None):
